@@ -9,7 +9,7 @@ from collections import OrderedDict, defaultdict
 from collections.abc import MutableMapping, Sequence
 from copy import copy as ccopy
 from copy import deepcopy
-from datetime import datetime
+import datetime
 from html import escape
 from typing import (
     TYPE_CHECKING,
@@ -266,6 +266,14 @@ class InferenceData(Mapping[str, xr.Dataset]):
             raise KeyError(key)
         return getattr(self, key)
 
+    def __setitem__(self, key: str, value: xr.Dataset):
+        """Set item by key and update group list accordingly."""
+        if key.startswith(WARMUP_TAG):
+            self._groups_warmup.append(key)
+        else:
+            self._groups.append(key)
+        setattr(self, key, value)
+
     def groups(self) -> List[str]:
         """Return all groups present in InferenceData object."""
         return self._groups_all
@@ -394,8 +402,10 @@ class InferenceData(Mapping[str, xr.Dataset]):
             )
 
         try:
-            with h5netcdf.File(filename, mode="r") if engine == "h5netcdf" else nc.Dataset(
-                filename, mode="r"
+            with (
+                h5netcdf.File(filename, mode="r")
+                if engine == "h5netcdf"
+                else nc.Dataset(filename, mode="r")
             ) as file_handle:
                 if base_group == "/":
                     data = file_handle
@@ -744,11 +754,11 @@ class InferenceData(Mapping[str, xr.Dataset]):
         if len(dfs) > 1:
             for group, df in dfs.items():
                 df.columns = [
-                    col
-                    if col in ("draw", "chain")
-                    else (group, *col)
-                    if isinstance(col, tuple)
-                    else (group, col)
+                    (
+                        col
+                        if col in ("draw", "chain")
+                        else (group, *col) if isinstance(col, tuple) else (group, col)
+                    )
                     for col in df.columns
                 ]
             dfs, *dfs_tail = list(dfs.values())
@@ -1475,12 +1485,12 @@ class InferenceData(Mapping[str, xr.Dataset]):
         Examples
         --------
         Add a ``log_likelihood`` group to the "rugby" example InferenceData after loading.
-        It originally doesn't have the ``log_likelihood`` group:
 
         .. jupyter-execute::
 
             import arviz as az
             idata = az.load_arviz_data("rugby")
+            del idata.log_likelihood
             idata2 = idata.copy()
             post = idata.posterior
             obs = idata.observed_data
@@ -1609,13 +1619,13 @@ class InferenceData(Mapping[str, xr.Dataset]):
         .. jupyter-execute::
 
             import arviz as az
-            idata = az.load_arviz_data("rugby")
+            idata = az.load_arviz_data("radon")
 
         Second InferenceData:
 
         .. jupyter-execute::
 
-            other_idata = az.load_arviz_data("radon")
+            other_idata = az.load_arviz_data("rugby")
 
         Call the ``extend`` method:
 
@@ -1687,6 +1697,7 @@ class InferenceData(Mapping[str, xr.Dataset]):
     compute = _extend_xr_method(xr.Dataset.compute)
     persist = _extend_xr_method(xr.Dataset.persist)
     quantile = _extend_xr_method(xr.Dataset.quantile)
+    close = _extend_xr_method(xr.Dataset.close)
 
     # The following lines use methods on xr.Dataset that are dynamically defined and attached.
     # As a result mypy cannot see them, so we have to suppress the resulting mypy errors.
@@ -1918,8 +1929,7 @@ def concat(
     copy: bool = True,
     inplace: "Literal[True]",
     reset_dim: bool = True,
-) -> None:
-    ...
+) -> None: ...
 
 
 @overload
@@ -1929,8 +1939,7 @@ def concat(
     copy: bool = True,
     inplace: "Literal[False]",
     reset_dim: bool = True,
-) -> InferenceData:
-    ...
+) -> InferenceData: ...
 
 
 @overload
@@ -1941,8 +1950,7 @@ def concat(
     copy: bool = True,
     inplace: "Literal[False]",
     reset_dim: bool = True,
-) -> InferenceData:
-    ...
+) -> InferenceData: ...
 
 
 @overload
@@ -1953,8 +1961,7 @@ def concat(
     copy: bool = True,
     inplace: "Literal[True]",
     reset_dim: bool = True,
-) -> None:
-    ...
+) -> None: ...
 
 
 @overload
@@ -1965,8 +1972,7 @@ def concat(
     copy: bool = True,
     inplace: bool = False,
     reset_dim: bool = True,
-) -> Optional[InferenceData]:
-    ...
+) -> Optional[InferenceData]: ...
 
 
 # pylint: disable=protected-access, inconsistent-return-statements
@@ -2083,7 +2089,7 @@ def concat(*args, dim=None, copy=True, inplace=False, reset_dim=True):
             else:
                 return args[0]
 
-    current_time = str(datetime.now())
+    current_time = datetime.datetime.now(datetime.timezone.utc).isoformat()
     combined_attr = defaultdict(list)
     for idata in args:
         for key, val in idata.attrs.items():
