@@ -270,12 +270,12 @@ def compare(
             weights[i] = u_weights / np.sum(u_weights)
 
         weights = weights.mean(axis=0)
-        ses = pd.Series(z_bs.std(axis=0), index=names)  # pylint: disable=no-member
+        ses = pd.Series(z_bs.std(axis=0), index=ics.index)  # pylint: disable=no-member
 
     elif method.lower() == "pseudo-bma":
         min_ic = ics.iloc[0][f"elpd_{ic}"]
         z_rv = np.exp((ics[f"elpd_{ic}"] - min_ic) / scale_value)
-        weights = z_rv / np.sum(z_rv)
+        weights = (z_rv / np.sum(z_rv)).to_numpy()
         ses = ics["se"]
 
     if np.any(weights):
@@ -471,7 +471,7 @@ def hdi(
         Refer to documentation of :func:`arviz.convert_to_dataset` for details.
     hdi_prob: float, optional
         Prob for which the highest density interval will be computed. Defaults to
-        ``stats.hdi_prob`` rcParam.
+        ``stats.ci_prob`` rcParam.
     circular: bool, optional
         Whether to compute the hdi taking into account `x` is a circular variable
         (in the range [-np.pi, np.pi]) or not. Defaults to False (i.e non-circular variables).
@@ -553,7 +553,7 @@ def hdi(
 
     """
     if hdi_prob is None:
-        hdi_prob = rcParams["stats.hdi_prob"]
+        hdi_prob = rcParams["stats.ci_prob"]
     elif not 1 >= hdi_prob > 0:
         raise ValueError("The value of hdi_prob should be in the interval (0, 1]")
 
@@ -711,15 +711,19 @@ def loo(data, pointwise=None, var_name=None, reff=None, scale=None):
     Returns
     -------
     ELPDData object (inherits from :class:`pandas.Series`) with the following row/attributes:
-    elpd: approximated expected log pointwise predictive density (elpd)
+    elpd_loo: approximated expected log pointwise predictive density (elpd)
     se: standard error of the elpd
     p_loo: effective number of parameters
-    shape_warn: bool
-        True if the estimated shape parameter of
-        Pareto distribution is greater than 0.7 for one or more samples
-    loo_i: array of pointwise predictive accuracy, only if pointwise True
+    n_samples: number of samples
+    n_data_points: number of data points
+    warning: bool
+        True if the estimated shape parameter of Pareto distribution is greater than
+        ``good_k``.
+    loo_i: :class:`~xarray.DataArray` with the pointwise predictive accuracy,
+            only if pointwise=True
     pareto_k: array of Pareto shape values, only if pointwise True
     scale: scale of the elpd
+    good_k: For a sample size S, the thresold is compute as min(1 - 1/log10(S), 0.7)
 
         The returned object has a custom print method that overrides pd.Series method.
 
@@ -785,13 +789,15 @@ def loo(data, pointwise=None, var_name=None, reff=None, scale=None):
     log_weights += log_likelihood
 
     warn_mg = False
-    if np.any(pareto_shape > 0.7):
+    good_k = min(1 - 1 / np.log10(n_samples), 0.7)
+
+    if np.any(pareto_shape > good_k):
         warnings.warn(
-            "Estimated shape parameter of Pareto distribution is greater than 0.7 for "
-            "one or more samples. You should consider using a more robust model, this is because "
-            "importance sampling is less likely to work well if the marginal posterior and "
-            "LOO posterior are very different. This is more likely to happen with a non-robust "
-            "model and highly influential observations."
+            f"Estimated shape parameter of Pareto distribution is greater than {good_k:.2f} "
+            "for one or more samples. You should consider using a more robust model, this is "
+            "because importance sampling is less likely to work well if the marginal posterior "
+            "and LOO posterior are very different. This is more likely to happen with a "
+            "non-robust model and highly influential observations."
         )
         warn_mg = True
 
@@ -816,8 +822,17 @@ def loo(data, pointwise=None, var_name=None, reff=None, scale=None):
 
     if not pointwise:
         return ELPDData(
-            data=[loo_lppd, loo_lppd_se, p_loo, n_samples, n_data_points, warn_mg, scale],
-            index=["elpd_loo", "se", "p_loo", "n_samples", "n_data_points", "warning", "scale"],
+            data=[loo_lppd, loo_lppd_se, p_loo, n_samples, n_data_points, warn_mg, scale, good_k],
+            index=[
+                "elpd_loo",
+                "se",
+                "p_loo",
+                "n_samples",
+                "n_data_points",
+                "warning",
+                "scale",
+                "good_k",
+            ],
         )
     if np.equal(loo_lppd, loo_lppd_i).all():  # pylint: disable=no-member
         warnings.warn(
@@ -835,6 +850,7 @@ def loo(data, pointwise=None, var_name=None, reff=None, scale=None):
             loo_lppd_i.rename("loo_i"),
             pareto_shape,
             scale,
+            good_k,
         ],
         index=[
             "elpd_loo",
@@ -846,6 +862,7 @@ def loo(data, pointwise=None, var_name=None, reff=None, scale=None):
             "loo_i",
             "pareto_k",
             "scale",
+            "good_k",
         ],
     )
 
@@ -879,7 +896,8 @@ def psislw(log_weights, reff=1.0):
 
     References
     ----------
-    * Vehtari et al. (2015) see https://arxiv.org/abs/1507.02646
+    * Vehtari et al. (2024). Pareto smoothed importance sampling. Journal of Machine
+      Learning Research, 25(72):1-58.
 
     See Also
     --------
@@ -899,6 +917,7 @@ def psislw(log_weights, reff=1.0):
            ...: az.psislw(-log_likelihood, reff=0.8)
 
     """
+    log_weights = deepcopy(log_weights)
     if hasattr(log_weights, "__sample__"):
         n_samples = len(log_weights.__sample__)
         shape = [
@@ -1322,7 +1341,7 @@ def summary(
     if labeller is None:
         labeller = BaseLabeller()
     if hdi_prob is None:
-        hdi_prob = rcParams["stats.hdi_prob"]
+        hdi_prob = rcParams["stats.ci_prob"]
     elif not 1 >= hdi_prob > 0:
         raise ValueError("The value of hdi_prob should be in the interval (0, 1]")
 
@@ -1565,7 +1584,9 @@ def waic(data, pointwise=None, var_name=None, scale=None, dask_kwargs=None):
     elpd_waic: approximated expected log pointwise predictive density (elpd)
     se: standard error of the elpd
     p_waic: effective number parameters
-    var_warn: bool
+    n_samples: number of samples
+    n_data_points: number of data points
+    warning: bool
         True if posterior variance of the log predictive densities exceeds 0.4
     waic_i: :class:`~xarray.DataArray` with the pointwise predictive accuracy,
             only if pointwise=True
