@@ -42,9 +42,12 @@ from ..helpers import (  # pylint: disable=unused-import
     draws,
     eight_schools_params,
     models,
-    running_on_ci,
 )
 
+# Check if dm-tree is installed
+dm_tree_installed = importlib.util.find_spec("tree") is not None  # pylint: disable=invalid-name
+skip_tests = (not dm_tree_installed) and ("ARVIZ_REQUIRE_ALL_DEPS" not in os.environ)
+
 
 @pytest.fixture(autouse=True)
 def no_remote_data(monkeypatch, tmpdir):
@@ -896,6 +899,11 @@ class TestInferenceData:  # pylint: disable=too-many-public-methods
         assert escape(repr(idata)) in html
         xr.set_options(display_style=display_style)
 
+    def test_setitem(self, data_random):
+        data_random["new_group"] = data_random.posterior
+        assert "new_group" in data_random.groups()
+        assert hasattr(data_random, "new_group")
+
     def test_add_groups(self, data_random):
         data = np.random.normal(size=(4, 500, 8))
         idata = data_random
@@ -1077,6 +1085,7 @@ def test_dict_to_dataset():
     assert set(dataset.b.coords) == {"chain", "draw", "c"}
 
 
+@pytest.mark.skipif(skip_tests, reason="test requires dm-tree which is not installed")
 def test_nested_dict_to_dataset():
     datadict = {
         "top": {"a": np.random.randn(100), "b": np.random.randn(1, 100, 10)},
@@ -1469,7 +1478,7 @@ class TestJSON:
 
 
 @pytest.mark.skipif(
-    not (importlib.util.find_spec("datatree") or running_on_ci()),
+    not (importlib.util.find_spec("datatree") or "ARVIZ_REQUIRE_ALL_DEPS" in os.environ),
     reason="test requires xarray-datatree library",
 )
 class TestDataTree:
